..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

API Docs
========

Extension
---------
.. automodule:: invenio_mail.ext
   :members:

Tasks
-----
.. autotask:: invenio_mail.tasks.send_email(data)

Templated Messages
------------------
.. automodule:: invenio_mail.api
   :members:
